Welcome to PyAppen's documentation!
=========================================

.. automodule:: appen.appen
    :members: AppenClient, AppenJob

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
